# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_task_details import CreateTaskDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateTaskFromRestTask(CreateTaskDetails):
    """
    The information about the Generic REST task.
    """

    #: A constant which can be used with the method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "GET"
    METHOD_TYPE_GET = "GET"

    #: A constant which can be used with the method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "POST"
    METHOD_TYPE_POST = "POST"

    #: A constant which can be used with the method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "PATCH"
    METHOD_TYPE_PATCH = "PATCH"

    #: A constant which can be used with the method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "DELETE"
    METHOD_TYPE_DELETE = "DELETE"

    #: A constant which can be used with the method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "PUT"
    METHOD_TYPE_PUT = "PUT"

    #: A constant which can be used with the api_call_mode property of a CreateTaskFromRestTask.
    #: This constant has a value of "SYNCHRONOUS"
    API_CALL_MODE_SYNCHRONOUS = "SYNCHRONOUS"

    #: A constant which can be used with the api_call_mode property of a CreateTaskFromRestTask.
    #: This constant has a value of "ASYNC_OCI_WORKREQUEST"
    API_CALL_MODE_ASYNC_OCI_WORKREQUEST = "ASYNC_OCI_WORKREQUEST"

    #: A constant which can be used with the cancel_method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "GET"
    CANCEL_METHOD_TYPE_GET = "GET"

    #: A constant which can be used with the cancel_method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "POST"
    CANCEL_METHOD_TYPE_POST = "POST"

    #: A constant which can be used with the cancel_method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "PATCH"
    CANCEL_METHOD_TYPE_PATCH = "PATCH"

    #: A constant which can be used with the cancel_method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "DELETE"
    CANCEL_METHOD_TYPE_DELETE = "DELETE"

    #: A constant which can be used with the cancel_method_type property of a CreateTaskFromRestTask.
    #: This constant has a value of "PUT"
    CANCEL_METHOD_TYPE_PUT = "PUT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateTaskFromRestTask object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CreateTaskFromRestTask.model_type` attribute
        of this class is ``REST_TASK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateTaskFromRestTask.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateTaskFromRestTask.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateTaskFromRestTask.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this CreateTaskFromRestTask.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this CreateTaskFromRestTask.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateTaskFromRestTask.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateTaskFromRestTask.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateTaskFromRestTask.
        :type identifier: str

        :param input_ports:
            The value to assign to the input_ports property of this CreateTaskFromRestTask.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this CreateTaskFromRestTask.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param parameters:
            The value to assign to the parameters property of this CreateTaskFromRestTask.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this CreateTaskFromRestTask.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this CreateTaskFromRestTask.
        :type config_provider_delegate: oci.data_integration.models.CreateConfigProvider

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateTaskFromRestTask.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        :param auth_details:
            The value to assign to the auth_details property of this CreateTaskFromRestTask.
        :type auth_details: oci.data_integration.models.AuthDetails

        :param endpoint:
            The value to assign to the endpoint property of this CreateTaskFromRestTask.
        :type endpoint: oci.data_integration.models.Expression

        :param method_type:
            The value to assign to the method_type property of this CreateTaskFromRestTask.
            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
        :type method_type: str

        :param headers:
            The value to assign to the headers property of this CreateTaskFromRestTask.
        :type headers: object

        :param json_data:
            The value to assign to the json_data property of this CreateTaskFromRestTask.
        :type json_data: str

        :param api_call_mode:
            The value to assign to the api_call_mode property of this CreateTaskFromRestTask.
            Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"
        :type api_call_mode: str

        :param cancel_endpoint:
            The value to assign to the cancel_endpoint property of this CreateTaskFromRestTask.
        :type cancel_endpoint: oci.data_integration.models.Expression

        :param cancel_method_type:
            The value to assign to the cancel_method_type property of this CreateTaskFromRestTask.
            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
        :type cancel_method_type: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'config_provider_delegate': 'CreateConfigProvider',
            'registry_metadata': 'RegistryMetadata',
            'auth_details': 'AuthDetails',
            'endpoint': 'Expression',
            'method_type': 'str',
            'headers': 'object',
            'json_data': 'str',
            'api_call_mode': 'str',
            'cancel_endpoint': 'Expression',
            'cancel_method_type': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'config_provider_delegate': 'configProviderDelegate',
            'registry_metadata': 'registryMetadata',
            'auth_details': 'authDetails',
            'endpoint': 'endpoint',
            'method_type': 'methodType',
            'headers': 'headers',
            'json_data': 'jsonData',
            'api_call_mode': 'apiCallMode',
            'cancel_endpoint': 'cancelEndpoint',
            'cancel_method_type': 'cancelMethodType'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._input_ports = None
        self._output_ports = None
        self._parameters = None
        self._op_config_values = None
        self._config_provider_delegate = None
        self._registry_metadata = None
        self._auth_details = None
        self._endpoint = None
        self._method_type = None
        self._headers = None
        self._json_data = None
        self._api_call_mode = None
        self._cancel_endpoint = None
        self._cancel_method_type = None
        self._model_type = 'REST_TASK'

    @property
    def auth_details(self):
        """
        Gets the auth_details of this CreateTaskFromRestTask.

        :return: The auth_details of this CreateTaskFromRestTask.
        :rtype: oci.data_integration.models.AuthDetails
        """
        return self._auth_details

    @auth_details.setter
    def auth_details(self, auth_details):
        """
        Sets the auth_details of this CreateTaskFromRestTask.

        :param auth_details: The auth_details of this CreateTaskFromRestTask.
        :type: oci.data_integration.models.AuthDetails
        """
        self._auth_details = auth_details

    @property
    def endpoint(self):
        """
        Gets the endpoint of this CreateTaskFromRestTask.

        :return: The endpoint of this CreateTaskFromRestTask.
        :rtype: oci.data_integration.models.Expression
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this CreateTaskFromRestTask.

        :param endpoint: The endpoint of this CreateTaskFromRestTask.
        :type: oci.data_integration.models.Expression
        """
        self._endpoint = endpoint

    @property
    def method_type(self):
        """
        Gets the method_type of this CreateTaskFromRestTask.
        The REST method to use.

        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"


        :return: The method_type of this CreateTaskFromRestTask.
        :rtype: str
        """
        return self._method_type

    @method_type.setter
    def method_type(self, method_type):
        """
        Sets the method_type of this CreateTaskFromRestTask.
        The REST method to use.


        :param method_type: The method_type of this CreateTaskFromRestTask.
        :type: str
        """
        allowed_values = ["GET", "POST", "PATCH", "DELETE", "PUT"]
        if not value_allowed_none_or_none_sentinel(method_type, allowed_values):
            raise ValueError(
                "Invalid value for `method_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._method_type = method_type

    @property
    def headers(self):
        """
        Gets the headers of this CreateTaskFromRestTask.
        The headers for the REST call.


        :return: The headers of this CreateTaskFromRestTask.
        :rtype: object
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """
        Sets the headers of this CreateTaskFromRestTask.
        The headers for the REST call.


        :param headers: The headers of this CreateTaskFromRestTask.
        :type: object
        """
        self._headers = headers

    @property
    def json_data(self):
        """
        Gets the json_data of this CreateTaskFromRestTask.
        JSON data for payload body.


        :return: The json_data of this CreateTaskFromRestTask.
        :rtype: str
        """
        return self._json_data

    @json_data.setter
    def json_data(self, json_data):
        """
        Sets the json_data of this CreateTaskFromRestTask.
        JSON data for payload body.


        :param json_data: The json_data of this CreateTaskFromRestTask.
        :type: str
        """
        self._json_data = json_data

    @property
    def api_call_mode(self):
        """
        Gets the api_call_mode of this CreateTaskFromRestTask.
        The invocation type to be used for Generic REST invocation.

        Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"


        :return: The api_call_mode of this CreateTaskFromRestTask.
        :rtype: str
        """
        return self._api_call_mode

    @api_call_mode.setter
    def api_call_mode(self, api_call_mode):
        """
        Sets the api_call_mode of this CreateTaskFromRestTask.
        The invocation type to be used for Generic REST invocation.


        :param api_call_mode: The api_call_mode of this CreateTaskFromRestTask.
        :type: str
        """
        allowed_values = ["SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"]
        if not value_allowed_none_or_none_sentinel(api_call_mode, allowed_values):
            raise ValueError(
                "Invalid value for `api_call_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._api_call_mode = api_call_mode

    @property
    def cancel_endpoint(self):
        """
        Gets the cancel_endpoint of this CreateTaskFromRestTask.

        :return: The cancel_endpoint of this CreateTaskFromRestTask.
        :rtype: oci.data_integration.models.Expression
        """
        return self._cancel_endpoint

    @cancel_endpoint.setter
    def cancel_endpoint(self, cancel_endpoint):
        """
        Sets the cancel_endpoint of this CreateTaskFromRestTask.

        :param cancel_endpoint: The cancel_endpoint of this CreateTaskFromRestTask.
        :type: oci.data_integration.models.Expression
        """
        self._cancel_endpoint = cancel_endpoint

    @property
    def cancel_method_type(self):
        """
        Gets the cancel_method_type of this CreateTaskFromRestTask.
        The REST method to use for canceling the original request.

        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"


        :return: The cancel_method_type of this CreateTaskFromRestTask.
        :rtype: str
        """
        return self._cancel_method_type

    @cancel_method_type.setter
    def cancel_method_type(self, cancel_method_type):
        """
        Sets the cancel_method_type of this CreateTaskFromRestTask.
        The REST method to use for canceling the original request.


        :param cancel_method_type: The cancel_method_type of this CreateTaskFromRestTask.
        :type: str
        """
        allowed_values = ["GET", "POST", "PATCH", "DELETE", "PUT"]
        if not value_allowed_none_or_none_sentinel(cancel_method_type, allowed_values):
            raise ValueError(
                "Invalid value for `cancel_method_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._cancel_method_type = cancel_method_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataEntity(object):
    """
    The data entity object.
    """

    #: A constant which can be used with the model_type property of a DataEntity.
    #: This constant has a value of "VIEW_ENTITY"
    MODEL_TYPE_VIEW_ENTITY = "VIEW_ENTITY"

    #: A constant which can be used with the model_type property of a DataEntity.
    #: This constant has a value of "TABLE_ENTITY"
    MODEL_TYPE_TABLE_ENTITY = "TABLE_ENTITY"

    #: A constant which can be used with the model_type property of a DataEntity.
    #: This constant has a value of "FILE_ENTITY"
    MODEL_TYPE_FILE_ENTITY = "FILE_ENTITY"

    #: A constant which can be used with the model_type property of a DataEntity.
    #: This constant has a value of "DATA_STORE_ENTITY"
    MODEL_TYPE_DATA_STORE_ENTITY = "DATA_STORE_ENTITY"

    def __init__(self, **kwargs):
        """
        Initializes a new DataEntity object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.DataEntityFromTable`
        * :class:`~oci.data_integration.models.DataEntityFromDataStore`
        * :class:`~oci.data_integration.models.DataEntityFromView`
        * :class:`~oci.data_integration.models.DataEntityFromFile`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DataEntity.
            Allowed values for this property are: "VIEW_ENTITY", "TABLE_ENTITY", "FILE_ENTITY", "DATA_STORE_ENTITY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param metadata:
            The value to assign to the metadata property of this DataEntity.
        :type metadata: oci.data_integration.models.ObjectMetadata

        """
        self.swagger_types = {
            'model_type': 'str',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'metadata': 'metadata'
        }

        self._model_type = None
        self._metadata = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'TABLE_ENTITY':
            return 'DataEntityFromTable'

        if type == 'DATA_STORE_ENTITY':
            return 'DataEntityFromDataStore'

        if type == 'VIEW_ENTITY':
            return 'DataEntityFromView'

        if type == 'FILE_ENTITY':
            return 'DataEntityFromFile'
        else:
            return 'DataEntity'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this DataEntity.
        The data entity type.

        Allowed values for this property are: "VIEW_ENTITY", "TABLE_ENTITY", "FILE_ENTITY", "DATA_STORE_ENTITY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this DataEntity.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this DataEntity.
        The data entity type.


        :param model_type: The model_type of this DataEntity.
        :type: str
        """
        allowed_values = ["VIEW_ENTITY", "TABLE_ENTITY", "FILE_ENTITY", "DATA_STORE_ENTITY"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def metadata(self):
        """
        Gets the metadata of this DataEntity.

        :return: The metadata of this DataEntity.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this DataEntity.

        :param metadata: The metadata of this DataEntity.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .application import Application
from .application_summary import ApplicationSummary
from .application_trace_config import ApplicationTraceConfig
from .change_application_compartment_details import ChangeApplicationCompartmentDetails
from .create_application_details import CreateApplicationDetails
from .create_function_details import CreateFunctionDetails
from .function import Function
from .function_summary import FunctionSummary
from .function_trace_config import FunctionTraceConfig
from .image_policy_config import ImagePolicyConfig
from .key_details import KeyDetails
from .update_application_details import UpdateApplicationDetails
from .update_function_details import UpdateFunctionDetails

# Maps type names to classes for functions services.
functions_type_mapping = {
    "Application": Application,
    "ApplicationSummary": ApplicationSummary,
    "ApplicationTraceConfig": ApplicationTraceConfig,
    "ChangeApplicationCompartmentDetails": ChangeApplicationCompartmentDetails,
    "CreateApplicationDetails": CreateApplicationDetails,
    "CreateFunctionDetails": CreateFunctionDetails,
    "Function": Function,
    "FunctionSummary": FunctionSummary,
    "FunctionTraceConfig": FunctionTraceConfig,
    "ImagePolicyConfig": ImagePolicyConfig,
    "KeyDetails": KeyDetails,
    "UpdateApplicationDetails": UpdateApplicationDetails,
    "UpdateFunctionDetails": UpdateFunctionDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseDetails(object):
    """
    Partial information about the database which includes id, name, type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DatabaseDetails.
        :type id: str

        :param database_id:
            The value to assign to the database_id property of this DatabaseDetails.
        :type database_id: str

        :param database_name:
            The value to assign to the database_name property of this DatabaseDetails.
        :type database_name: str

        :param database_display_name:
            The value to assign to the database_display_name property of this DatabaseDetails.
        :type database_display_name: str

        :param database_type:
            The value to assign to the database_type property of this DatabaseDetails.
        :type database_type: str

        :param database_version:
            The value to assign to the database_version property of this DatabaseDetails.
        :type database_version: str

        :param instances:
            The value to assign to the instances property of this DatabaseDetails.
        :type instances: list[oci.opsi.models.HostInstanceMap]

        """
        self.swagger_types = {
            'id': 'str',
            'database_id': 'str',
            'database_name': 'str',
            'database_display_name': 'str',
            'database_type': 'str',
            'database_version': 'str',
            'instances': 'list[HostInstanceMap]'
        }

        self.attribute_map = {
            'id': 'id',
            'database_id': 'databaseId',
            'database_name': 'databaseName',
            'database_display_name': 'databaseDisplayName',
            'database_type': 'databaseType',
            'database_version': 'databaseVersion',
            'instances': 'instances'
        }

        self._id = None
        self._database_id = None
        self._database_name = None
        self._database_display_name = None
        self._database_type = None
        self._database_version = None
        self._instances = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DatabaseDetails.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DatabaseDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatabaseDetails.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DatabaseDetails.
        :type: str
        """
        self._id = id

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this DatabaseDetails.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The database_id of this DatabaseDetails.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this DatabaseDetails.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this DatabaseDetails.
        :type: str
        """
        self._database_id = database_id

    @property
    def database_name(self):
        """
        **[Required]** Gets the database_name of this DatabaseDetails.
        The database name. The database name is unique within the tenancy.


        :return: The database_name of this DatabaseDetails.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this DatabaseDetails.
        The database name. The database name is unique within the tenancy.


        :param database_name: The database_name of this DatabaseDetails.
        :type: str
        """
        self._database_name = database_name

    @property
    def database_display_name(self):
        """
        Gets the database_display_name of this DatabaseDetails.
        The user-friendly name for the database. The name does not have to be unique.


        :return: The database_display_name of this DatabaseDetails.
        :rtype: str
        """
        return self._database_display_name

    @database_display_name.setter
    def database_display_name(self, database_display_name):
        """
        Sets the database_display_name of this DatabaseDetails.
        The user-friendly name for the database. The name does not have to be unique.


        :param database_display_name: The database_display_name of this DatabaseDetails.
        :type: str
        """
        self._database_display_name = database_display_name

    @property
    def database_type(self):
        """
        **[Required]** Gets the database_type of this DatabaseDetails.
        Operations Insights internal representation of the database type.


        :return: The database_type of this DatabaseDetails.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this DatabaseDetails.
        Operations Insights internal representation of the database type.


        :param database_type: The database_type of this DatabaseDetails.
        :type: str
        """
        self._database_type = database_type

    @property
    def database_version(self):
        """
        Gets the database_version of this DatabaseDetails.
        The version of the database.


        :return: The database_version of this DatabaseDetails.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this DatabaseDetails.
        The version of the database.


        :param database_version: The database_version of this DatabaseDetails.
        :type: str
        """
        self._database_version = database_version

    @property
    def instances(self):
        """
        Gets the instances of this DatabaseDetails.
        Array of hostname and instance name.


        :return: The instances of this DatabaseDetails.
        :rtype: list[oci.opsi.models.HostInstanceMap]
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """
        Sets the instances of this DatabaseDetails.
        Array of hostname and instance name.


        :param instances: The instances of this DatabaseDetails.
        :type: list[oci.opsi.models.HostInstanceMap]
        """
        self._instances = instances

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfigValue(object):
    """
    configuration item for multi list data type
    """

    #: A constant which can be used with the list_type property of a ConfigValue.
    #: This constant has a value of "MANAGED"
    LIST_TYPE_MANAGED = "MANAGED"

    #: A constant which can be used with the list_type property of a ConfigValue.
    #: This constant has a value of "CUSTOM"
    LIST_TYPE_CUSTOM = "CUSTOM"

    def __init__(self, **kwargs):
        """
        Initializes a new ConfigValue object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param list_type:
            The value to assign to the list_type property of this ConfigValue.
            Allowed values for this property are: "MANAGED", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type list_type: str

        :param managed_list_type:
            The value to assign to the managed_list_type property of this ConfigValue.
        :type managed_list_type: str

        :param value:
            The value to assign to the value property of this ConfigValue.
        :type value: str

        """
        self.swagger_types = {
            'list_type': 'str',
            'managed_list_type': 'str',
            'value': 'str'
        }

        self.attribute_map = {
            'list_type': 'listType',
            'managed_list_type': 'managedListType',
            'value': 'value'
        }

        self._list_type = None
        self._managed_list_type = None
        self._value = None

    @property
    def list_type(self):
        """
        **[Required]** Gets the list_type of this ConfigValue.
        configuration list item type, either CUSTOM or MANAGED

        Allowed values for this property are: "MANAGED", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The list_type of this ConfigValue.
        :rtype: str
        """
        return self._list_type

    @list_type.setter
    def list_type(self, list_type):
        """
        Sets the list_type of this ConfigValue.
        configuration list item type, either CUSTOM or MANAGED


        :param list_type: The list_type of this ConfigValue.
        :type: str
        """
        allowed_values = ["MANAGED", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(list_type, allowed_values):
            list_type = 'UNKNOWN_ENUM_VALUE'
        self._list_type = list_type

    @property
    def managed_list_type(self):
        """
        **[Required]** Gets the managed_list_type of this ConfigValue.
        type of the managed list


        :return: The managed_list_type of this ConfigValue.
        :rtype: str
        """
        return self._managed_list_type

    @managed_list_type.setter
    def managed_list_type(self, managed_list_type):
        """
        Sets the managed_list_type of this ConfigValue.
        type of the managed list


        :param managed_list_type: The managed_list_type of this ConfigValue.
        :type: str
        """
        self._managed_list_type = managed_list_type

    @property
    def value(self):
        """
        **[Required]** Gets the value of this ConfigValue.
        configuration value


        :return: The value of this ConfigValue.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigValue.
        configuration value


        :param value: The value of this ConfigValue.
        :type: str
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateVmClusterNetworkDetails(object):
    """
    Details for an Exadata VM cluster network. Applies to Exadata Cloud@Customer instances only.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateVmClusterNetworkDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param scans:
            The value to assign to the scans property of this UpdateVmClusterNetworkDetails.
        :type scans: list[oci.database.models.ScanDetails]

        :param dns:
            The value to assign to the dns property of this UpdateVmClusterNetworkDetails.
        :type dns: list[str]

        :param ntp:
            The value to assign to the ntp property of this UpdateVmClusterNetworkDetails.
        :type ntp: list[str]

        :param vm_networks:
            The value to assign to the vm_networks property of this UpdateVmClusterNetworkDetails.
        :type vm_networks: list[oci.database.models.VmNetworkDetails]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateVmClusterNetworkDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateVmClusterNetworkDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'scans': 'list[ScanDetails]',
            'dns': 'list[str]',
            'ntp': 'list[str]',
            'vm_networks': 'list[VmNetworkDetails]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'scans': 'scans',
            'dns': 'dns',
            'ntp': 'ntp',
            'vm_networks': 'vmNetworks',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._scans = None
        self._dns = None
        self._ntp = None
        self._vm_networks = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def scans(self):
        """
        Gets the scans of this UpdateVmClusterNetworkDetails.
        The SCAN details.


        :return: The scans of this UpdateVmClusterNetworkDetails.
        :rtype: list[oci.database.models.ScanDetails]
        """
        return self._scans

    @scans.setter
    def scans(self, scans):
        """
        Sets the scans of this UpdateVmClusterNetworkDetails.
        The SCAN details.


        :param scans: The scans of this UpdateVmClusterNetworkDetails.
        :type: list[oci.database.models.ScanDetails]
        """
        self._scans = scans

    @property
    def dns(self):
        """
        Gets the dns of this UpdateVmClusterNetworkDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :return: The dns of this UpdateVmClusterNetworkDetails.
        :rtype: list[str]
        """
        return self._dns

    @dns.setter
    def dns(self, dns):
        """
        Sets the dns of this UpdateVmClusterNetworkDetails.
        The list of DNS server IP addresses. Maximum of 3 allowed.


        :param dns: The dns of this UpdateVmClusterNetworkDetails.
        :type: list[str]
        """
        self._dns = dns

    @property
    def ntp(self):
        """
        Gets the ntp of this UpdateVmClusterNetworkDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :return: The ntp of this UpdateVmClusterNetworkDetails.
        :rtype: list[str]
        """
        return self._ntp

    @ntp.setter
    def ntp(self, ntp):
        """
        Sets the ntp of this UpdateVmClusterNetworkDetails.
        The list of NTP server IP addresses. Maximum of 3 allowed.


        :param ntp: The ntp of this UpdateVmClusterNetworkDetails.
        :type: list[str]
        """
        self._ntp = ntp

    @property
    def vm_networks(self):
        """
        Gets the vm_networks of this UpdateVmClusterNetworkDetails.
        Details of the client and backup networks.


        :return: The vm_networks of this UpdateVmClusterNetworkDetails.
        :rtype: list[oci.database.models.VmNetworkDetails]
        """
        return self._vm_networks

    @vm_networks.setter
    def vm_networks(self, vm_networks):
        """
        Sets the vm_networks of this UpdateVmClusterNetworkDetails.
        Details of the client and backup networks.


        :param vm_networks: The vm_networks of this UpdateVmClusterNetworkDetails.
        :type: list[oci.database.models.VmNetworkDetails]
        """
        self._vm_networks = vm_networks

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateVmClusterNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateVmClusterNetworkDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateVmClusterNetworkDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateVmClusterNetworkDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateVmClusterNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateVmClusterNetworkDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateVmClusterNetworkDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateVmClusterNetworkDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PropertyOverride(object):
    """
    Property overrides at the scope of objects.
    For example, if you want to use logSourceName as 'xyz' for all objects that conatins string 'abc/' then
    define matchType as 'contains', matchValue as 'abc/', propertyName as 'logSourceName' and propertyValue as 'xyz'.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PropertyOverride object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param match_type:
            The value to assign to the match_type property of this PropertyOverride.
        :type match_type: str

        :param match_value:
            The value to assign to the match_value property of this PropertyOverride.
        :type match_value: str

        :param property_name:
            The value to assign to the property_name property of this PropertyOverride.
        :type property_name: str

        :param property_value:
            The value to assign to the property_value property of this PropertyOverride.
        :type property_value: str

        """
        self.swagger_types = {
            'match_type': 'str',
            'match_value': 'str',
            'property_name': 'str',
            'property_value': 'str'
        }

        self.attribute_map = {
            'match_type': 'matchType',
            'match_value': 'matchValue',
            'property_name': 'propertyName',
            'property_value': 'propertyValue'
        }

        self._match_type = None
        self._match_value = None
        self._property_name = None
        self._property_value = None

    @property
    def match_type(self):
        """
        Gets the match_type of this PropertyOverride.
        Match Type. Accepted values are: contains.


        :return: The match_type of this PropertyOverride.
        :rtype: str
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """
        Sets the match_type of this PropertyOverride.
        Match Type. Accepted values are: contains.


        :param match_type: The match_type of this PropertyOverride.
        :type: str
        """
        self._match_type = match_type

    @property
    def match_value(self):
        """
        Gets the match_value of this PropertyOverride.
        Match Value.


        :return: The match_value of this PropertyOverride.
        :rtype: str
        """
        return self._match_value

    @match_value.setter
    def match_value(self, match_value):
        """
        Sets the match_value of this PropertyOverride.
        Match Value.


        :param match_value: The match_value of this PropertyOverride.
        :type: str
        """
        self._match_value = match_value

    @property
    def property_name(self):
        """
        Gets the property_name of this PropertyOverride.
        Property to override. Accepted values are: logSourceName, charEncoding.


        :return: The property_name of this PropertyOverride.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this PropertyOverride.
        Property to override. Accepted values are: logSourceName, charEncoding.


        :param property_name: The property_name of this PropertyOverride.
        :type: str
        """
        self._property_name = property_name

    @property
    def property_value(self):
        """
        Gets the property_value of this PropertyOverride.
        Value of the property.


        :return: The property_value of this PropertyOverride.
        :rtype: str
        """
        return self._property_value

    @property_value.setter
    def property_value(self, property_value):
        """
        Sets the property_value of this PropertyOverride.
        Value of the property.


        :param property_value: The property_value of this PropertyOverride.
        :type: str
        """
        self._property_value = property_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Service(object):
    """
    An object that represents one or multiple Oracle services that you can enable for a
    :class:`ServiceGateway`. In the User Guide topic
    `Access to Oracle Services: Service Gateway`__, the
    term *service CIDR label* is used to refer to the string that represents the regional public
    IP address ranges of the Oracle service or services covered by a given `Service` object. That
    unique string is the value of the `Service` object's `cidrBlock` attribute.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/servicegateway.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Service object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cidr_block:
            The value to assign to the cidr_block property of this Service.
        :type cidr_block: str

        :param description:
            The value to assign to the description property of this Service.
        :type description: str

        :param id:
            The value to assign to the id property of this Service.
        :type id: str

        :param name:
            The value to assign to the name property of this Service.
        :type name: str

        """
        self.swagger_types = {
            'cidr_block': 'str',
            'description': 'str',
            'id': 'str',
            'name': 'str'
        }

        self.attribute_map = {
            'cidr_block': 'cidrBlock',
            'description': 'description',
            'id': 'id',
            'name': 'name'
        }

        self._cidr_block = None
        self._description = None
        self._id = None
        self._name = None

    @property
    def cidr_block(self):
        """
        **[Required]** Gets the cidr_block of this Service.
        A string that represents the regional public IP address ranges for the Oracle service or
        services covered by this `Service` object. Also known as the `Service` object's *service
        CIDR label*.

        When you set up a route rule to route traffic to the service gateway, use this value as the
        rule's destination. See :class:`RouteTable`. Also, when you set up
        a security list rule to cover traffic with the service gateway, use the `cidrBlock` value
        as the rule's destination (for an egress rule) or the source (for an ingress rule).
        See :class:`SecurityList`.

        Example: `oci-phx-objectstorage`


        :return: The cidr_block of this Service.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this Service.
        A string that represents the regional public IP address ranges for the Oracle service or
        services covered by this `Service` object. Also known as the `Service` object's *service
        CIDR label*.

        When you set up a route rule to route traffic to the service gateway, use this value as the
        rule's destination. See :class:`RouteTable`. Also, when you set up
        a security list rule to cover traffic with the service gateway, use the `cidrBlock` value
        as the rule's destination (for an egress rule) or the source (for an ingress rule).
        See :class:`SecurityList`.

        Example: `oci-phx-objectstorage`


        :param cidr_block: The cidr_block of this Service.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Service.
        Description of the Oracle service or services covered by this `Service` object.

        Example: `OCI PHX Object Storage`


        :return: The description of this Service.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Service.
        Description of the Oracle service or services covered by this `Service` object.

        Example: `OCI PHX Object Storage`


        :param description: The description of this Service.
        :type: str
        """
        self._description = description

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Service.
        The `Service` object's `OCID`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Service.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Service.
        The `Service` object's `OCID`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Service.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Service.
        Name of the `Service` object. This name can change and is not guaranteed to be unique.

        Example: `OCI PHX Object Storage`


        :return: The name of this Service.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Service.
        Name of the `Service` object. This name can change and is not guaranteed to be unique.

        Example: `OCI PHX Object Storage`


        :param name: The name of this Service.
        :type: str
        """
        self._name = name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_backup_destination_details import CreateBackupDestinationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateRecoveryApplianceBackupDestinationDetails(CreateBackupDestinationDetails):
    """
    Used for creating Recovery Appliance backup destinations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateRecoveryApplianceBackupDestinationDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateRecoveryApplianceBackupDestinationDetails.type` attribute
        of this class is ``RECOVERY_APPLIANCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type compartment_id: str

        :param type:
            The value to assign to the type property of this CreateRecoveryApplianceBackupDestinationDetails.
            Allowed values for this property are: "NFS", "RECOVERY_APPLIANCE"
        :type type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param connection_string:
            The value to assign to the connection_string property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type connection_string: str

        :param vpc_users:
            The value to assign to the vpc_users property of this CreateRecoveryApplianceBackupDestinationDetails.
        :type vpc_users: list[str]

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'connection_string': 'str',
            'vpc_users': 'list[str]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'type': 'type',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'connection_string': 'connectionString',
            'vpc_users': 'vpcUsers'
        }

        self._display_name = None
        self._compartment_id = None
        self._type = None
        self._freeform_tags = None
        self._defined_tags = None
        self._connection_string = None
        self._vpc_users = None
        self._type = 'RECOVERY_APPLIANCE'

    @property
    def connection_string(self):
        """
        **[Required]** Gets the connection_string of this CreateRecoveryApplianceBackupDestinationDetails.
        The connection string for connecting to the Recovery Appliance.


        :return: The connection_string of this CreateRecoveryApplianceBackupDestinationDetails.
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this CreateRecoveryApplianceBackupDestinationDetails.
        The connection string for connecting to the Recovery Appliance.


        :param connection_string: The connection_string of this CreateRecoveryApplianceBackupDestinationDetails.
        :type: str
        """
        self._connection_string = connection_string

    @property
    def vpc_users(self):
        """
        **[Required]** Gets the vpc_users of this CreateRecoveryApplianceBackupDestinationDetails.
        The Virtual Private Catalog (VPC) users that are used to access the Recovery Appliance.


        :return: The vpc_users of this CreateRecoveryApplianceBackupDestinationDetails.
        :rtype: list[str]
        """
        return self._vpc_users

    @vpc_users.setter
    def vpc_users(self, vpc_users):
        """
        Sets the vpc_users of this CreateRecoveryApplianceBackupDestinationDetails.
        The Virtual Private Catalog (VPC) users that are used to access the Recovery Appliance.


        :param vpc_users: The vpc_users of this CreateRecoveryApplianceBackupDestinationDetails.
        :type: list[str]
        """
        self._vpc_users = vpc_users

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackupDestinationDetails(object):
    """
    Backup destination details
    """

    #: A constant which can be used with the type property of a BackupDestinationDetails.
    #: This constant has a value of "NFS"
    TYPE_NFS = "NFS"

    #: A constant which can be used with the type property of a BackupDestinationDetails.
    #: This constant has a value of "RECOVERY_APPLIANCE"
    TYPE_RECOVERY_APPLIANCE = "RECOVERY_APPLIANCE"

    #: A constant which can be used with the type property of a BackupDestinationDetails.
    #: This constant has a value of "OBJECT_STORE"
    TYPE_OBJECT_STORE = "OBJECT_STORE"

    #: A constant which can be used with the type property of a BackupDestinationDetails.
    #: This constant has a value of "LOCAL"
    TYPE_LOCAL = "LOCAL"

    def __init__(self, **kwargs):
        """
        Initializes a new BackupDestinationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this BackupDestinationDetails.
            Allowed values for this property are: "NFS", "RECOVERY_APPLIANCE", "OBJECT_STORE", "LOCAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param id:
            The value to assign to the id property of this BackupDestinationDetails.
        :type id: str

        :param vpc_user:
            The value to assign to the vpc_user property of this BackupDestinationDetails.
        :type vpc_user: str

        :param vpc_password:
            The value to assign to the vpc_password property of this BackupDestinationDetails.
        :type vpc_password: str

        :param internet_proxy:
            The value to assign to the internet_proxy property of this BackupDestinationDetails.
        :type internet_proxy: str

        """
        self.swagger_types = {
            'type': 'str',
            'id': 'str',
            'vpc_user': 'str',
            'vpc_password': 'str',
            'internet_proxy': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'id': 'id',
            'vpc_user': 'vpcUser',
            'vpc_password': 'vpcPassword',
            'internet_proxy': 'internetProxy'
        }

        self._type = None
        self._id = None
        self._vpc_user = None
        self._vpc_password = None
        self._internet_proxy = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this BackupDestinationDetails.
        Type of the database backup destination.

        Allowed values for this property are: "NFS", "RECOVERY_APPLIANCE", "OBJECT_STORE", "LOCAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this BackupDestinationDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this BackupDestinationDetails.
        Type of the database backup destination.


        :param type: The type of this BackupDestinationDetails.
        :type: str
        """
        allowed_values = ["NFS", "RECOVERY_APPLIANCE", "OBJECT_STORE", "LOCAL"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def id(self):
        """
        Gets the id of this BackupDestinationDetails.
        The `OCID`__ of the backup destination.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this BackupDestinationDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BackupDestinationDetails.
        The `OCID`__ of the backup destination.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this BackupDestinationDetails.
        :type: str
        """
        self._id = id

    @property
    def vpc_user(self):
        """
        Gets the vpc_user of this BackupDestinationDetails.
        For a RECOVERY_APPLIANCE backup destination, the Virtual Private Catalog (VPC) user that is used to access the Recovery Appliance.


        :return: The vpc_user of this BackupDestinationDetails.
        :rtype: str
        """
        return self._vpc_user

    @vpc_user.setter
    def vpc_user(self, vpc_user):
        """
        Sets the vpc_user of this BackupDestinationDetails.
        For a RECOVERY_APPLIANCE backup destination, the Virtual Private Catalog (VPC) user that is used to access the Recovery Appliance.


        :param vpc_user: The vpc_user of this BackupDestinationDetails.
        :type: str
        """
        self._vpc_user = vpc_user

    @property
    def vpc_password(self):
        """
        Gets the vpc_password of this BackupDestinationDetails.
        For a RECOVERY_APPLIANCE backup destination, the password for the VPC user that is used to access the Recovery Appliance.


        :return: The vpc_password of this BackupDestinationDetails.
        :rtype: str
        """
        return self._vpc_password

    @vpc_password.setter
    def vpc_password(self, vpc_password):
        """
        Sets the vpc_password of this BackupDestinationDetails.
        For a RECOVERY_APPLIANCE backup destination, the password for the VPC user that is used to access the Recovery Appliance.


        :param vpc_password: The vpc_password of this BackupDestinationDetails.
        :type: str
        """
        self._vpc_password = vpc_password

    @property
    def internet_proxy(self):
        """
        Gets the internet_proxy of this BackupDestinationDetails.
        Proxy URL to connect to object store.


        :return: The internet_proxy of this BackupDestinationDetails.
        :rtype: str
        """
        return self._internet_proxy

    @internet_proxy.setter
    def internet_proxy(self, internet_proxy):
        """
        Sets the internet_proxy of this BackupDestinationDetails.
        Proxy URL to connect to object store.


        :param internet_proxy: The internet_proxy of this BackupDestinationDetails.
        :type: str
        """
        self._internet_proxy = internet_proxy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataAssetDetails(object):
    """
    Properties used in data asset create operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataAssetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDataAssetDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateDataAssetDetails.
        :type description: str

        :param type_key:
            The value to assign to the type_key property of this CreateDataAssetDetails.
        :type type_key: str

        :param custom_property_members:
            The value to assign to the custom_property_members property of this CreateDataAssetDetails.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertySetUsage]

        :param properties:
            The value to assign to the properties property of this CreateDataAssetDetails.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'type_key': 'str',
            'custom_property_members': 'list[CustomPropertySetUsage]',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'type_key': 'typeKey',
            'custom_property_members': 'customPropertyMembers',
            'properties': 'properties'
        }

        self._display_name = None
        self._description = None
        self._type_key = None
        self._custom_property_members = None
        self._properties = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateDataAssetDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDataAssetDetails.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateDataAssetDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateDataAssetDetails.
        Detailed description of the data asset.


        :return: The description of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDataAssetDetails.
        Detailed description of the data asset.


        :param description: The description of this CreateDataAssetDetails.
        :type: str
        """
        self._description = description

    @property
    def type_key(self):
        """
        **[Required]** Gets the type_key of this CreateDataAssetDetails.
        The key of the data asset type. This can be obtained via the '/types' endpoint.


        :return: The type_key of this CreateDataAssetDetails.
        :rtype: str
        """
        return self._type_key

    @type_key.setter
    def type_key(self, type_key):
        """
        Sets the type_key of this CreateDataAssetDetails.
        The key of the data asset type. This can be obtained via the '/types' endpoint.


        :param type_key: The type_key of this CreateDataAssetDetails.
        :type: str
        """
        self._type_key = type_key

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this CreateDataAssetDetails.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this CreateDataAssetDetails.
        :rtype: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this CreateDataAssetDetails.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this CreateDataAssetDetails.
        :type: list[oci.data_catalog.models.CustomPropertySetUsage]
        """
        self._custom_property_members = custom_property_members

    @property
    def properties(self):
        """
        Gets the properties of this CreateDataAssetDetails.
        A map of maps that contains the properties which are specific to the data asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category. To determine the set of optional and
        required properties for a data asset type, a query can be done on '/types?type=dataAsset' that returns a
        collection of all data asset types. The appropriate data asset type, which includes definitions of all of
        it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :return: The properties of this CreateDataAssetDetails.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CreateDataAssetDetails.
        A map of maps that contains the properties which are specific to the data asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category. To determine the set of optional and
        required properties for a data asset type, a query can be done on '/types?type=dataAsset' that returns a
        collection of all data asset types. The appropriate data asset type, which includes definitions of all of
        it's properties, can be identified from this collection.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :param properties: The properties of this CreateDataAssetDetails.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Update(object):
    """
    Update model.
    """

    #: A constant which can be used with the last_action property of a Update.
    #: This constant has a value of "ROLLING_APPLY"
    LAST_ACTION_ROLLING_APPLY = "ROLLING_APPLY"

    #: A constant which can be used with the last_action property of a Update.
    #: This constant has a value of "NON_ROLLING_APPLY"
    LAST_ACTION_NON_ROLLING_APPLY = "NON_ROLLING_APPLY"

    #: A constant which can be used with the last_action property of a Update.
    #: This constant has a value of "PRECHECK"
    LAST_ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the last_action property of a Update.
    #: This constant has a value of "ROLLBACK"
    LAST_ACTION_ROLLBACK = "ROLLBACK"

    #: A constant which can be used with the available_actions property of a Update.
    #: This constant has a value of "ROLLING_APPLY"
    AVAILABLE_ACTIONS_ROLLING_APPLY = "ROLLING_APPLY"

    #: A constant which can be used with the available_actions property of a Update.
    #: This constant has a value of "NON_ROLLING_APPLY"
    AVAILABLE_ACTIONS_NON_ROLLING_APPLY = "NON_ROLLING_APPLY"

    #: A constant which can be used with the available_actions property of a Update.
    #: This constant has a value of "PRECHECK"
    AVAILABLE_ACTIONS_PRECHECK = "PRECHECK"

    #: A constant which can be used with the available_actions property of a Update.
    #: This constant has a value of "ROLLBACK"
    AVAILABLE_ACTIONS_ROLLBACK = "ROLLBACK"

    #: A constant which can be used with the update_type property of a Update.
    #: This constant has a value of "GI_UPGRADE"
    UPDATE_TYPE_GI_UPGRADE = "GI_UPGRADE"

    #: A constant which can be used with the update_type property of a Update.
    #: This constant has a value of "GI_PATCH"
    UPDATE_TYPE_GI_PATCH = "GI_PATCH"

    #: A constant which can be used with the update_type property of a Update.
    #: This constant has a value of "OS_UPDATE"
    UPDATE_TYPE_OS_UPDATE = "OS_UPDATE"

    #: A constant which can be used with the lifecycle_state property of a Update.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a Update.
    #: This constant has a value of "SUCCESS"
    LIFECYCLE_STATE_SUCCESS = "SUCCESS"

    #: A constant which can be used with the lifecycle_state property of a Update.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a Update.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Update object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Update.
        :type id: str

        :param description:
            The value to assign to the description property of this Update.
        :type description: str

        :param last_action:
            The value to assign to the last_action property of this Update.
            Allowed values for this property are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type last_action: str

        :param available_actions:
            The value to assign to the available_actions property of this Update.
            Allowed values for items in this list are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type available_actions: list[str]

        :param update_type:
            The value to assign to the update_type property of this Update.
            Allowed values for this property are: "GI_UPGRADE", "GI_PATCH", "OS_UPDATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type update_type: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Update.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Update.
            Allowed values for this property are: "AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_released:
            The value to assign to the time_released property of this Update.
        :type time_released: datetime

        :param version:
            The value to assign to the version property of this Update.
        :type version: str

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'last_action': 'str',
            'available_actions': 'list[str]',
            'update_type': 'str',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_released': 'datetime',
            'version': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'last_action': 'lastAction',
            'available_actions': 'availableActions',
            'update_type': 'updateType',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_released': 'timeReleased',
            'version': 'version'
        }

        self._id = None
        self._description = None
        self._last_action = None
        self._available_actions = None
        self._update_type = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_released = None
        self._version = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Update.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this Update.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Update.
        The `OCID`__ of the maintenance update.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this Update.
        :type: str
        """
        self._id = id

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Update.
        Details of the maintenance update package.


        :return: The description of this Update.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Update.
        Details of the maintenance update package.


        :param description: The description of this Update.
        :type: str
        """
        self._description = description

    @property
    def last_action(self):
        """
        Gets the last_action of this Update.
        The update action.

        Allowed values for this property are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The last_action of this Update.
        :rtype: str
        """
        return self._last_action

    @last_action.setter
    def last_action(self, last_action):
        """
        Sets the last_action of this Update.
        The update action.


        :param last_action: The last_action of this Update.
        :type: str
        """
        allowed_values = ["ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK"]
        if not value_allowed_none_or_none_sentinel(last_action, allowed_values):
            last_action = 'UNKNOWN_ENUM_VALUE'
        self._last_action = last_action

    @property
    def available_actions(self):
        """
        Gets the available_actions of this Update.
        The possible actions performed by the update operation on the infrastructure components.

        Allowed values for items in this list are: "ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The available_actions of this Update.
        :rtype: list[str]
        """
        return self._available_actions

    @available_actions.setter
    def available_actions(self, available_actions):
        """
        Sets the available_actions of this Update.
        The possible actions performed by the update operation on the infrastructure components.


        :param available_actions: The available_actions of this Update.
        :type: list[str]
        """
        allowed_values = ["ROLLING_APPLY", "NON_ROLLING_APPLY", "PRECHECK", "ROLLBACK"]
        if available_actions:
            available_actions[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in available_actions]
        self._available_actions = available_actions

    @property
    def update_type(self):
        """
        **[Required]** Gets the update_type of this Update.
        The type of cloud VM cluster maintenance update.

        Allowed values for this property are: "GI_UPGRADE", "GI_PATCH", "OS_UPDATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The update_type of this Update.
        :rtype: str
        """
        return self._update_type

    @update_type.setter
    def update_type(self, update_type):
        """
        Sets the update_type of this Update.
        The type of cloud VM cluster maintenance update.


        :param update_type: The update_type of this Update.
        :type: str
        """
        allowed_values = ["GI_UPGRADE", "GI_PATCH", "OS_UPDATE"]
        if not value_allowed_none_or_none_sentinel(update_type, allowed_values):
            update_type = 'UNKNOWN_ENUM_VALUE'
        self._update_type = update_type

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Update.
        Descriptive text providing additional details about the lifecycle state.


        :return: The lifecycle_details of this Update.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Update.
        Descriptive text providing additional details about the lifecycle state.


        :param lifecycle_details: The lifecycle_details of this Update.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Update.
        The current state of the maintenance update. Dependent on value of `lastAction`.

        Allowed values for this property are: "AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Update.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Update.
        The current state of the maintenance update. Dependent on value of `lastAction`.


        :param lifecycle_state: The lifecycle_state of this Update.
        :type: str
        """
        allowed_values = ["AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_released(self):
        """
        **[Required]** Gets the time_released of this Update.
        The date and time the maintenance update was released.


        :return: The time_released of this Update.
        :rtype: datetime
        """
        return self._time_released

    @time_released.setter
    def time_released(self, time_released):
        """
        Sets the time_released of this Update.
        The date and time the maintenance update was released.


        :param time_released: The time_released of this Update.
        :type: datetime
        """
        self._time_released = time_released

    @property
    def version(self):
        """
        **[Required]** Gets the version of this Update.
        The version of the maintenance update package.


        :return: The version of this Update.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Update.
        The version of the maintenance update package.


        :param version: The version of this Update.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateConnectDescriptor(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Connect Descriptor details. Required for Manual and UserManagerOci connection types.
    If a Private Endpoint was specified for the Connection, the host should contain a valid IP address.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateConnectDescriptor object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param host:
            The value to assign to the host property of this CreateConnectDescriptor.
        :type host: str

        :param port:
            The value to assign to the port property of this CreateConnectDescriptor.
        :type port: int

        :param database_service_name:
            The value to assign to the database_service_name property of this CreateConnectDescriptor.
        :type database_service_name: str

        :param connect_string:
            The value to assign to the connect_string property of this CreateConnectDescriptor.
        :type connect_string: str

        """
        self.swagger_types = {
            'host': 'str',
            'port': 'int',
            'database_service_name': 'str',
            'connect_string': 'str'
        }

        self.attribute_map = {
            'host': 'host',
            'port': 'port',
            'database_service_name': 'databaseServiceName',
            'connect_string': 'connectString'
        }

        self._host = None
        self._port = None
        self._database_service_name = None
        self._connect_string = None

    @property
    def host(self):
        """
        Gets the host of this CreateConnectDescriptor.
        Host or IP address of the connect descriptor. Required if no connectString was specified.


        :return: The host of this CreateConnectDescriptor.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this CreateConnectDescriptor.
        Host or IP address of the connect descriptor. Required if no connectString was specified.


        :param host: The host of this CreateConnectDescriptor.
        :type: str
        """
        self._host = host

    @property
    def port(self):
        """
        Gets the port of this CreateConnectDescriptor.
        Port of the connect descriptor. Required if no connectString was specified.


        :return: The port of this CreateConnectDescriptor.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this CreateConnectDescriptor.
        Port of the connect descriptor. Required if no connectString was specified.


        :param port: The port of this CreateConnectDescriptor.
        :type: int
        """
        self._port = port

    @property
    def database_service_name(self):
        """
        Gets the database_service_name of this CreateConnectDescriptor.
        Database service name. Required if no connectString was specified.


        :return: The database_service_name of this CreateConnectDescriptor.
        :rtype: str
        """
        return self._database_service_name

    @database_service_name.setter
    def database_service_name(self, database_service_name):
        """
        Sets the database_service_name of this CreateConnectDescriptor.
        Database service name. Required if no connectString was specified.


        :param database_service_name: The database_service_name of this CreateConnectDescriptor.
        :type: str
        """
        self._database_service_name = database_service_name

    @property
    def connect_string(self):
        """
        Gets the connect_string of this CreateConnectDescriptor.
        Connect String. Required if no host, port nor databaseServiceName were specified.
        If a Private Endpoint was specified in the Connection, the host entry should be a valid IP address.
        Supported formats:
        Easy connect: <host>:<port>/<db_service_name>
        Long format: (description= (address=(port=<port>)(host=<host>))(connect_data=(service_name=<db_service_name>)))


        :return: The connect_string of this CreateConnectDescriptor.
        :rtype: str
        """
        return self._connect_string

    @connect_string.setter
    def connect_string(self, connect_string):
        """
        Sets the connect_string of this CreateConnectDescriptor.
        Connect String. Required if no host, port nor databaseServiceName were specified.
        If a Private Endpoint was specified in the Connection, the host entry should be a valid IP address.
        Supported formats:
        Easy connect: <host>:<port>/<db_service_name>
        Long format: (description= (address=(port=<port>)(host=<host>))(connect_data=(service_name=<db_service_name>)))


        :param connect_string: The connect_string of this CreateConnectDescriptor.
        :type: str
        """
        self._connect_string = connect_string

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSessionTargetResourceDetails(object):
    """
    Details about a bastion session's target resource.
    """

    #: A constant which can be used with the session_type property of a CreateSessionTargetResourceDetails.
    #: This constant has a value of "MANAGED_SSH"
    SESSION_TYPE_MANAGED_SSH = "MANAGED_SSH"

    #: A constant which can be used with the session_type property of a CreateSessionTargetResourceDetails.
    #: This constant has a value of "PORT_FORWARDING"
    SESSION_TYPE_PORT_FORWARDING = "PORT_FORWARDING"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSessionTargetResourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.bastion.models.CreateManagedSshSessionTargetResourceDetails`
        * :class:`~oci.bastion.models.CreatePortForwardingSessionTargetResourceDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param session_type:
            The value to assign to the session_type property of this CreateSessionTargetResourceDetails.
            Allowed values for this property are: "MANAGED_SSH", "PORT_FORWARDING"
        :type session_type: str

        :param target_resource_port:
            The value to assign to the target_resource_port property of this CreateSessionTargetResourceDetails.
        :type target_resource_port: int

        """
        self.swagger_types = {
            'session_type': 'str',
            'target_resource_port': 'int'
        }

        self.attribute_map = {
            'session_type': 'sessionType',
            'target_resource_port': 'targetResourcePort'
        }

        self._session_type = None
        self._target_resource_port = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['sessionType']

        if type == 'MANAGED_SSH':
            return 'CreateManagedSshSessionTargetResourceDetails'

        if type == 'PORT_FORWARDING':
            return 'CreatePortForwardingSessionTargetResourceDetails'
        else:
            return 'CreateSessionTargetResourceDetails'

    @property
    def session_type(self):
        """
        **[Required]** Gets the session_type of this CreateSessionTargetResourceDetails.
        The session type.

        Allowed values for this property are: "MANAGED_SSH", "PORT_FORWARDING"


        :return: The session_type of this CreateSessionTargetResourceDetails.
        :rtype: str
        """
        return self._session_type

    @session_type.setter
    def session_type(self, session_type):
        """
        Sets the session_type of this CreateSessionTargetResourceDetails.
        The session type.


        :param session_type: The session_type of this CreateSessionTargetResourceDetails.
        :type: str
        """
        allowed_values = ["MANAGED_SSH", "PORT_FORWARDING"]
        if not value_allowed_none_or_none_sentinel(session_type, allowed_values):
            raise ValueError(
                "Invalid value for `session_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._session_type = session_type

    @property
    def target_resource_port(self):
        """
        Gets the target_resource_port of this CreateSessionTargetResourceDetails.
        The port number to connect to on the target resource.


        :return: The target_resource_port of this CreateSessionTargetResourceDetails.
        :rtype: int
        """
        return self._target_resource_port

    @target_resource_port.setter
    def target_resource_port(self, target_resource_port):
        """
        Sets the target_resource_port of this CreateSessionTargetResourceDetails.
        The port number to connect to on the target resource.


        :param target_resource_port: The target_resource_port of this CreateSessionTargetResourceDetails.
        :type: int
        """
        self._target_resource_port = target_resource_port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrDbMetricSummary(object):
    """
    The summary of the AWR metric data for a particular metric at a specific time.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrDbMetricSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this AwrDbMetricSummary.
        :type name: str

        :param timestamp:
            The value to assign to the timestamp property of this AwrDbMetricSummary.
        :type timestamp: datetime

        :param avg_value:
            The value to assign to the avg_value property of this AwrDbMetricSummary.
        :type avg_value: float

        :param min_value:
            The value to assign to the min_value property of this AwrDbMetricSummary.
        :type min_value: float

        :param max_value:
            The value to assign to the max_value property of this AwrDbMetricSummary.
        :type max_value: float

        """
        self.swagger_types = {
            'name': 'str',
            'timestamp': 'datetime',
            'avg_value': 'float',
            'min_value': 'float',
            'max_value': 'float'
        }

        self.attribute_map = {
            'name': 'name',
            'timestamp': 'timestamp',
            'avg_value': 'avgValue',
            'min_value': 'minValue',
            'max_value': 'maxValue'
        }

        self._name = None
        self._timestamp = None
        self._avg_value = None
        self._min_value = None
        self._max_value = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AwrDbMetricSummary.
        The name of the metric.


        :return: The name of this AwrDbMetricSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AwrDbMetricSummary.
        The name of the metric.


        :param name: The name of this AwrDbMetricSummary.
        :type: str
        """
        self._name = name

    @property
    def timestamp(self):
        """
        Gets the timestamp of this AwrDbMetricSummary.
        The time of the sampling.


        :return: The timestamp of this AwrDbMetricSummary.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this AwrDbMetricSummary.
        The time of the sampling.


        :param timestamp: The timestamp of this AwrDbMetricSummary.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def avg_value(self):
        """
        Gets the avg_value of this AwrDbMetricSummary.
        The average value of the sampling period.


        :return: The avg_value of this AwrDbMetricSummary.
        :rtype: float
        """
        return self._avg_value

    @avg_value.setter
    def avg_value(self, avg_value):
        """
        Sets the avg_value of this AwrDbMetricSummary.
        The average value of the sampling period.


        :param avg_value: The avg_value of this AwrDbMetricSummary.
        :type: float
        """
        self._avg_value = avg_value

    @property
    def min_value(self):
        """
        Gets the min_value of this AwrDbMetricSummary.
        The minimum value of the sampling period.


        :return: The min_value of this AwrDbMetricSummary.
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """
        Sets the min_value of this AwrDbMetricSummary.
        The minimum value of the sampling period.


        :param min_value: The min_value of this AwrDbMetricSummary.
        :type: float
        """
        self._min_value = min_value

    @property
    def max_value(self):
        """
        Gets the max_value of this AwrDbMetricSummary.
        The maximum value of the sampling period.


        :return: The max_value of this AwrDbMetricSummary.
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """
        Sets the max_value of this AwrDbMetricSummary.
        The maximum value of the sampling period.


        :param max_value: The max_value of this AwrDbMetricSummary.
        :type: float
        """
        self._max_value = max_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WorkRequestResource(object):
    """
    A resource related to a Data Flow work request.
    """

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "CREATED"
    ACTION_TYPE_CREATED = "CREATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "UPDATED"
    ACTION_TYPE_UPDATED = "UPDATED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "DELETED"
    ACTION_TYPE_DELETED = "DELETED"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "INPROGRESS"
    ACTION_TYPE_INPROGRESS = "INPROGRESS"

    #: A constant which can be used with the action_type property of a WorkRequestResource.
    #: This constant has a value of "RELATED"
    ACTION_TYPE_RELATED = "RELATED"

    def __init__(self, **kwargs):
        """
        Initializes a new WorkRequestResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_type:
            The value to assign to the action_type property of this WorkRequestResource.
            Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "INPROGRESS", "RELATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_type: str

        :param id:
            The value to assign to the id property of this WorkRequestResource.
        :type id: int

        :param resource_id:
            The value to assign to the resource_id property of this WorkRequestResource.
        :type resource_id: str

        :param resource_type:
            The value to assign to the resource_type property of this WorkRequestResource.
        :type resource_type: str

        :param resource_uri:
            The value to assign to the resource_uri property of this WorkRequestResource.
        :type resource_uri: str

        :param work_requestid:
            The value to assign to the work_requestid property of this WorkRequestResource.
        :type work_requestid: str

        """
        self.swagger_types = {
            'action_type': 'str',
            'id': 'int',
            'resource_id': 'str',
            'resource_type': 'str',
            'resource_uri': 'str',
            'work_requestid': 'str'
        }

        self.attribute_map = {
            'action_type': 'actionType',
            'id': 'id',
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'resource_uri': 'resourceUri',
            'work_requestid': 'workRequestid'
        }

        self._action_type = None
        self._id = None
        self._resource_id = None
        self._resource_type = None
        self._resource_uri = None
        self._work_requestid = None

    @property
    def action_type(self):
        """
        **[Required]** Gets the action_type of this WorkRequestResource.
        The way in which this resource is affected by the work tracked in the work request.

        Allowed values for this property are: "CREATED", "UPDATED", "DELETED", "INPROGRESS", "RELATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_type of this WorkRequestResource.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this WorkRequestResource.
        The way in which this resource is affected by the work tracked in the work request.


        :param action_type: The action_type of this WorkRequestResource.
        :type: str
        """
        allowed_values = ["CREATED", "UPDATED", "DELETED", "INPROGRESS", "RELATED"]
        if not value_allowed_none_or_none_sentinel(action_type, allowed_values):
            action_type = 'UNKNOWN_ENUM_VALUE'
        self._action_type = action_type

    @property
    def id(self):
        """
        Gets the id of this WorkRequestResource.
        The id of a work request resource object.


        :return: The id of this WorkRequestResource.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkRequestResource.
        The id of a work request resource object.


        :param id: The id of this WorkRequestResource.
        :type: int
        """
        self._id = id

    @property
    def resource_id(self):
        """
        **[Required]** Gets the resource_id of this WorkRequestResource.
        The id of the releated resource. See resourceType to identity the specific type of resource.


        :return: The resource_id of this WorkRequestResource.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this WorkRequestResource.
        The id of the releated resource. See resourceType to identity the specific type of resource.


        :param resource_id: The resource_id of this WorkRequestResource.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this WorkRequestResource.
        The type of resource.  See resourceId for the id of the specific resource.


        :return: The resource_type of this WorkRequestResource.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this WorkRequestResource.
        The type of resource.  See resourceId for the id of the specific resource.


        :param resource_type: The resource_type of this WorkRequestResource.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def resource_uri(self):
        """
        Gets the resource_uri of this WorkRequestResource.
        The URI path that the user can use to get access to the resource metadata


        :return: The resource_uri of this WorkRequestResource.
        :rtype: str
        """
        return self._resource_uri

    @resource_uri.setter
    def resource_uri(self, resource_uri):
        """
        Sets the resource_uri of this WorkRequestResource.
        The URI path that the user can use to get access to the resource metadata


        :param resource_uri: The resource_uri of this WorkRequestResource.
        :type: str
        """
        self._resource_uri = resource_uri

    @property
    def work_requestid(self):
        """
        Gets the work_requestid of this WorkRequestResource.
        The OCID of a work request.


        :return: The work_requestid of this WorkRequestResource.
        :rtype: str
        """
        return self._work_requestid

    @work_requestid.setter
    def work_requestid(self, work_requestid):
        """
        Sets the work_requestid of this WorkRequestResource.
        The OCID of a work request.


        :param work_requestid: The work_requestid of this WorkRequestResource.
        :type: str
        """
        self._work_requestid = work_requestid

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTextSummary(object):
    """
    SQL Text details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTextSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sql_identifier:
            The value to assign to the sql_identifier property of this SqlTextSummary.
        :type sql_identifier: str

        :param id:
            The value to assign to the id property of this SqlTextSummary.
        :type id: str

        :param database_id:
            The value to assign to the database_id property of this SqlTextSummary.
        :type database_id: str

        :param sql_text:
            The value to assign to the sql_text property of this SqlTextSummary.
        :type sql_text: str

        """
        self.swagger_types = {
            'sql_identifier': 'str',
            'id': 'str',
            'database_id': 'str',
            'sql_text': 'str'
        }

        self.attribute_map = {
            'sql_identifier': 'sqlIdentifier',
            'id': 'id',
            'database_id': 'databaseId',
            'sql_text': 'sqlText'
        }

        self._sql_identifier = None
        self._id = None
        self._database_id = None
        self._sql_text = None

    @property
    def sql_identifier(self):
        """
        **[Required]** Gets the sql_identifier of this SqlTextSummary.
        Unique SQL_ID for a SQL Statement.


        :return: The sql_identifier of this SqlTextSummary.
        :rtype: str
        """
        return self._sql_identifier

    @sql_identifier.setter
    def sql_identifier(self, sql_identifier):
        """
        Sets the sql_identifier of this SqlTextSummary.
        Unique SQL_ID for a SQL Statement.


        :param sql_identifier: The sql_identifier of this SqlTextSummary.
        :type: str
        """
        self._sql_identifier = sql_identifier

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SqlTextSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this SqlTextSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SqlTextSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this SqlTextSummary.
        :type: str
        """
        self._id = id

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this SqlTextSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The database_id of this SqlTextSummary.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this SqlTextSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this SqlTextSummary.
        :type: str
        """
        self._database_id = database_id

    @property
    def sql_text(self):
        """
        **[Required]** Gets the sql_text of this SqlTextSummary.
        SQL Text


        :return: The sql_text of this SqlTextSummary.
        :rtype: str
        """
        return self._sql_text

    @sql_text.setter
    def sql_text(self, sql_text):
        """
        Sets the sql_text of this SqlTextSummary.
        SQL Text


        :param sql_text: The sql_text of this SqlTextSummary.
        :type: str
        """
        self._sql_text = sql_text

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgRouteDistribution(object):
    """
    A route distribution establishes how routes get imported into DRG route tables and exported through the DRG attachments.

    A route distribution is a list of statements. Each statement consists of a set of matches, all of which must be `True` in order for
    the statement's action to take place. Each statement determines which routes are propagated.

    You can assign a route distribution as a route table's import distribution. The statements in an import
    route distribution specify how how incoming route advertisements through a referenced attachment or all attachments of a certain type are inserted into the route table.

    You can assign a route distribution as a DRG attachment's export distribution. Export route distribution statements specify how routes in a
    DRG attachment's assigned table are advertised out through the attachment. When a DRG attachment is created, a route distribution is created with a
    single ACCEPT statement with an empty match criteria (empty match criteria implies match ALL).
    Exporting routes through VCN attachments is unsupported, so no VCN attachments are assigned an export distribution.

    The two auto-generated DRG route tables (one as the default for VCN attachments, and the other for all other types of attachments)
    are each assigned an auto generated import route distribution. The default VCN table's import distribution has a single statement with empty match criteria statement to import routes from
    each DRG attachment type. The other table's import distribution has a statement to import routes from attachments with the VCN type.

    The route distribution is always in the same compartment as the DRG.
    """

    #: A constant which can be used with the lifecycle_state property of a DrgRouteDistribution.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a DrgRouteDistribution.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a DrgRouteDistribution.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a DrgRouteDistribution.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the distribution_type property of a DrgRouteDistribution.
    #: This constant has a value of "IMPORT"
    DISTRIBUTION_TYPE_IMPORT = "IMPORT"

    #: A constant which can be used with the distribution_type property of a DrgRouteDistribution.
    #: This constant has a value of "EXPORT"
    DISTRIBUTION_TYPE_EXPORT = "EXPORT"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgRouteDistribution object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param drg_id:
            The value to assign to the drg_id property of this DrgRouteDistribution.
        :type drg_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DrgRouteDistribution.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this DrgRouteDistribution.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this DrgRouteDistribution.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DrgRouteDistribution.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this DrgRouteDistribution.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DrgRouteDistribution.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this DrgRouteDistribution.
        :type time_created: datetime

        :param distribution_type:
            The value to assign to the distribution_type property of this DrgRouteDistribution.
            Allowed values for this property are: "IMPORT", "EXPORT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type distribution_type: str

        """
        self.swagger_types = {
            'drg_id': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'distribution_type': 'str'
        }

        self.attribute_map = {
            'drg_id': 'drgId',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'distribution_type': 'distributionType'
        }

        self._drg_id = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._time_created = None
        self._distribution_type = None

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this DrgRouteDistribution.
        The `OCID`__ of the DRG that contains this route distribution.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The drg_id of this DrgRouteDistribution.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this DrgRouteDistribution.
        The `OCID`__ of the DRG that contains this route distribution.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param drg_id: The drg_id of this DrgRouteDistribution.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DrgRouteDistribution.
        The `OCID`__ of the compartment containing the route distribution.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DrgRouteDistribution.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DrgRouteDistribution.
        The `OCID`__ of the compartment containing the route distribution.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DrgRouteDistribution.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DrgRouteDistribution.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DrgRouteDistribution.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DrgRouteDistribution.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DrgRouteDistribution.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this DrgRouteDistribution.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this DrgRouteDistribution.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DrgRouteDistribution.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this DrgRouteDistribution.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DrgRouteDistribution.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DrgRouteDistribution.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DrgRouteDistribution.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DrgRouteDistribution.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DrgRouteDistribution.
        The route distribution's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DrgRouteDistribution.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DrgRouteDistribution.
        The route distribution's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DrgRouteDistribution.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DrgRouteDistribution.
        The route distribution's current state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DrgRouteDistribution.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DrgRouteDistribution.
        The route distribution's current state.


        :param lifecycle_state: The lifecycle_state of this DrgRouteDistribution.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this DrgRouteDistribution.
        The date and time the route distribution was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DrgRouteDistribution.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DrgRouteDistribution.
        The date and time the route distribution was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DrgRouteDistribution.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def distribution_type(self):
        """
        **[Required]** Gets the distribution_type of this DrgRouteDistribution.
        Whether this distribution defines how routes get imported into route tables or exported through DRG attachments.

        Allowed values for this property are: "IMPORT", "EXPORT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The distribution_type of this DrgRouteDistribution.
        :rtype: str
        """
        return self._distribution_type

    @distribution_type.setter
    def distribution_type(self, distribution_type):
        """
        Sets the distribution_type of this DrgRouteDistribution.
        Whether this distribution defines how routes get imported into route tables or exported through DRG attachments.


        :param distribution_type: The distribution_type of this DrgRouteDistribution.
        :type: str
        """
        allowed_values = ["IMPORT", "EXPORT"]
        if not value_allowed_none_or_none_sentinel(distribution_type, allowed_values):
            distribution_type = 'UNKNOWN_ENUM_VALUE'
        self._distribution_type = distribution_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_database_registration_compartment_details import ChangeDatabaseRegistrationCompartmentDetails
from .change_deployment_backup_compartment_details import ChangeDeploymentBackupCompartmentDetails
from .change_deployment_compartment_details import ChangeDeploymentCompartmentDetails
from .create_database_registration_details import CreateDatabaseRegistrationDetails
from .create_deployment_backup_details import CreateDeploymentBackupDetails
from .create_deployment_details import CreateDeploymentDetails
from .create_ogg_deployment_details import CreateOggDeploymentDetails
from .database_registration import DatabaseRegistration
from .database_registration_collection import DatabaseRegistrationCollection
from .database_registration_summary import DatabaseRegistrationSummary
from .default_restore_deployment_details import DefaultRestoreDeploymentDetails
from .default_start_deployment_details import DefaultStartDeploymentDetails
from .default_stop_deployment_details import DefaultStopDeploymentDetails
from .deployment import Deployment
from .deployment_backup import DeploymentBackup
from .deployment_backup_collection import DeploymentBackupCollection
from .deployment_backup_summary import DeploymentBackupSummary
from .deployment_collection import DeploymentCollection
from .deployment_summary import DeploymentSummary
from .ogg_deployment import OggDeployment
from .restore_deployment_details import RestoreDeploymentDetails
from .start_deployment_details import StartDeploymentDetails
from .stop_deployment_details import StopDeploymentDetails
from .update_database_registration_details import UpdateDatabaseRegistrationDetails
from .update_deployment_backup_details import UpdateDeploymentBackupDetails
from .update_deployment_details import UpdateDeploymentDetails
from .update_ogg_deployment_details import UpdateOggDeploymentDetails
from .upgrade_deployment_current_release_details import UpgradeDeploymentCurrentReleaseDetails
from .upgrade_deployment_details import UpgradeDeploymentDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource

# Maps type names to classes for golden_gate services.
golden_gate_type_mapping = {
    "ChangeDatabaseRegistrationCompartmentDetails": ChangeDatabaseRegistrationCompartmentDetails,
    "ChangeDeploymentBackupCompartmentDetails": ChangeDeploymentBackupCompartmentDetails,
    "ChangeDeploymentCompartmentDetails": ChangeDeploymentCompartmentDetails,
    "CreateDatabaseRegistrationDetails": CreateDatabaseRegistrationDetails,
    "CreateDeploymentBackupDetails": CreateDeploymentBackupDetails,
    "CreateDeploymentDetails": CreateDeploymentDetails,
    "CreateOggDeploymentDetails": CreateOggDeploymentDetails,
    "DatabaseRegistration": DatabaseRegistration,
    "DatabaseRegistrationCollection": DatabaseRegistrationCollection,
    "DatabaseRegistrationSummary": DatabaseRegistrationSummary,
    "DefaultRestoreDeploymentDetails": DefaultRestoreDeploymentDetails,
    "DefaultStartDeploymentDetails": DefaultStartDeploymentDetails,
    "DefaultStopDeploymentDetails": DefaultStopDeploymentDetails,
    "Deployment": Deployment,
    "DeploymentBackup": DeploymentBackup,
    "DeploymentBackupCollection": DeploymentBackupCollection,
    "DeploymentBackupSummary": DeploymentBackupSummary,
    "DeploymentCollection": DeploymentCollection,
    "DeploymentSummary": DeploymentSummary,
    "OggDeployment": OggDeployment,
    "RestoreDeploymentDetails": RestoreDeploymentDetails,
    "StartDeploymentDetails": StartDeploymentDetails,
    "StopDeploymentDetails": StopDeploymentDetails,
    "UpdateDatabaseRegistrationDetails": UpdateDatabaseRegistrationDetails,
    "UpdateDeploymentBackupDetails": UpdateDeploymentBackupDetails,
    "UpdateDeploymentDetails": UpdateDeploymentDetails,
    "UpdateOggDeploymentDetails": UpdateOggDeploymentDetails,
    "UpgradeDeploymentCurrentReleaseDetails": UpgradeDeploymentCurrentReleaseDetails,
    "UpgradeDeploymentDetails": UpgradeDeploymentDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlStatisticsTimeSeriesAggregationCollection(object):
    """
    SQL performance statistics over the selected time window.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlStatisticsTimeSeriesAggregationCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sql_identifier:
            The value to assign to the sql_identifier property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type sql_identifier: str

        :param time_interval_start:
            The value to assign to the time_interval_start property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type time_interval_start: datetime

        :param time_interval_end:
            The value to assign to the time_interval_end property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type time_interval_end: datetime

        :param item_duration_in_ms:
            The value to assign to the item_duration_in_ms property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type item_duration_in_ms: int

        :param end_timestamps:
            The value to assign to the end_timestamps property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type end_timestamps: list[datetime]

        :param items:
            The value to assign to the items property of this SqlStatisticsTimeSeriesAggregationCollection.
        :type items: list[oci.opsi.models.SqlStatisticsTimeSeriesAggregation]

        """
        self.swagger_types = {
            'sql_identifier': 'str',
            'time_interval_start': 'datetime',
            'time_interval_end': 'datetime',
            'item_duration_in_ms': 'int',
            'end_timestamps': 'list[datetime]',
            'items': 'list[SqlStatisticsTimeSeriesAggregation]'
        }

        self.attribute_map = {
            'sql_identifier': 'sqlIdentifier',
            'time_interval_start': 'timeIntervalStart',
            'time_interval_end': 'timeIntervalEnd',
            'item_duration_in_ms': 'itemDurationInMs',
            'end_timestamps': 'endTimestamps',
            'items': 'items'
        }

        self._sql_identifier = None
        self._time_interval_start = None
        self._time_interval_end = None
        self._item_duration_in_ms = None
        self._end_timestamps = None
        self._items = None

    @property
    def sql_identifier(self):
        """
        **[Required]** Gets the sql_identifier of this SqlStatisticsTimeSeriesAggregationCollection.
        Unique SQL_ID for a SQL Statement.


        :return: The sql_identifier of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: str
        """
        return self._sql_identifier

    @sql_identifier.setter
    def sql_identifier(self, sql_identifier):
        """
        Sets the sql_identifier of this SqlStatisticsTimeSeriesAggregationCollection.
        Unique SQL_ID for a SQL Statement.


        :param sql_identifier: The sql_identifier of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: str
        """
        self._sql_identifier = sql_identifier

    @property
    def time_interval_start(self):
        """
        **[Required]** Gets the time_interval_start of this SqlStatisticsTimeSeriesAggregationCollection.
        The start timestamp that was passed into the request.


        :return: The time_interval_start of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: datetime
        """
        return self._time_interval_start

    @time_interval_start.setter
    def time_interval_start(self, time_interval_start):
        """
        Sets the time_interval_start of this SqlStatisticsTimeSeriesAggregationCollection.
        The start timestamp that was passed into the request.


        :param time_interval_start: The time_interval_start of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: datetime
        """
        self._time_interval_start = time_interval_start

    @property
    def time_interval_end(self):
        """
        **[Required]** Gets the time_interval_end of this SqlStatisticsTimeSeriesAggregationCollection.
        The end timestamp that was passed into the request.


        :return: The time_interval_end of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: datetime
        """
        return self._time_interval_end

    @time_interval_end.setter
    def time_interval_end(self, time_interval_end):
        """
        Sets the time_interval_end of this SqlStatisticsTimeSeriesAggregationCollection.
        The end timestamp that was passed into the request.


        :param time_interval_end: The time_interval_end of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: datetime
        """
        self._time_interval_end = time_interval_end

    @property
    def item_duration_in_ms(self):
        """
        **[Required]** Gets the item_duration_in_ms of this SqlStatisticsTimeSeriesAggregationCollection.
        Time duration in milliseconds between data points (one hour or one day).


        :return: The item_duration_in_ms of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: int
        """
        return self._item_duration_in_ms

    @item_duration_in_ms.setter
    def item_duration_in_ms(self, item_duration_in_ms):
        """
        Sets the item_duration_in_ms of this SqlStatisticsTimeSeriesAggregationCollection.
        Time duration in milliseconds between data points (one hour or one day).


        :param item_duration_in_ms: The item_duration_in_ms of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: int
        """
        self._item_duration_in_ms = item_duration_in_ms

    @property
    def end_timestamps(self):
        """
        Gets the end_timestamps of this SqlStatisticsTimeSeriesAggregationCollection.
        Array comprising of all the sampling period end timestamps in RFC 3339 format.


        :return: The end_timestamps of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: list[datetime]
        """
        return self._end_timestamps

    @end_timestamps.setter
    def end_timestamps(self, end_timestamps):
        """
        Sets the end_timestamps of this SqlStatisticsTimeSeriesAggregationCollection.
        Array comprising of all the sampling period end timestamps in RFC 3339 format.


        :param end_timestamps: The end_timestamps of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: list[datetime]
        """
        self._end_timestamps = end_timestamps

    @property
    def items(self):
        """
        **[Required]** Gets the items of this SqlStatisticsTimeSeriesAggregationCollection.
        Array of SQL performance statistics across databases.


        :return: The items of this SqlStatisticsTimeSeriesAggregationCollection.
        :rtype: list[oci.opsi.models.SqlStatisticsTimeSeriesAggregation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this SqlStatisticsTimeSeriesAggregationCollection.
        Array of SQL performance statistics across databases.


        :param items: The items of this SqlStatisticsTimeSeriesAggregationCollection.
        :type: list[oci.opsi.models.SqlStatisticsTimeSeriesAggregation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Publisher(object):
    """
    The model for a publisher.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Publisher object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Publisher.
        :type id: str

        :param name:
            The value to assign to the name property of this Publisher.
        :type name: str

        :param description:
            The value to assign to the description property of this Publisher.
        :type description: str

        :param year_founded:
            The value to assign to the year_founded property of this Publisher.
        :type year_founded: int

        :param website_url:
            The value to assign to the website_url property of this Publisher.
        :type website_url: str

        :param contact_email:
            The value to assign to the contact_email property of this Publisher.
        :type contact_email: str

        :param contact_phone:
            The value to assign to the contact_phone property of this Publisher.
        :type contact_phone: str

        :param hq_address:
            The value to assign to the hq_address property of this Publisher.
        :type hq_address: str

        :param logo:
            The value to assign to the logo property of this Publisher.
        :type logo: oci.marketplace.models.UploadData

        :param links:
            The value to assign to the links property of this Publisher.
        :type links: list[oci.marketplace.models.Link]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'year_founded': 'int',
            'website_url': 'str',
            'contact_email': 'str',
            'contact_phone': 'str',
            'hq_address': 'str',
            'logo': 'UploadData',
            'links': 'list[Link]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'year_founded': 'yearFounded',
            'website_url': 'websiteUrl',
            'contact_email': 'contactEmail',
            'contact_phone': 'contactPhone',
            'hq_address': 'hqAddress',
            'logo': 'logo',
            'links': 'links'
        }

        self._id = None
        self._name = None
        self._description = None
        self._year_founded = None
        self._website_url = None
        self._contact_email = None
        self._contact_phone = None
        self._hq_address = None
        self._logo = None
        self._links = None

    @property
    def id(self):
        """
        Gets the id of this Publisher.
        Unique identifier for the publisher.


        :return: The id of this Publisher.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Publisher.
        Unique identifier for the publisher.


        :param id: The id of this Publisher.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Publisher.
        The name of the publisher.


        :return: The name of this Publisher.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Publisher.
        The name of the publisher.


        :param name: The name of this Publisher.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Publisher.
        A description of the publisher.


        :return: The description of this Publisher.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Publisher.
        A description of the publisher.


        :param description: The description of this Publisher.
        :type: str
        """
        self._description = description

    @property
    def year_founded(self):
        """
        Gets the year_founded of this Publisher.
        The year the publisher's company or organization was founded.


        :return: The year_founded of this Publisher.
        :rtype: int
        """
        return self._year_founded

    @year_founded.setter
    def year_founded(self, year_founded):
        """
        Sets the year_founded of this Publisher.
        The year the publisher's company or organization was founded.


        :param year_founded: The year_founded of this Publisher.
        :type: int
        """
        self._year_founded = year_founded

    @property
    def website_url(self):
        """
        Gets the website_url of this Publisher.
        The publisher's website.


        :return: The website_url of this Publisher.
        :rtype: str
        """
        return self._website_url

    @website_url.setter
    def website_url(self, website_url):
        """
        Sets the website_url of this Publisher.
        The publisher's website.


        :param website_url: The website_url of this Publisher.
        :type: str
        """
        self._website_url = website_url

    @property
    def contact_email(self):
        """
        Gets the contact_email of this Publisher.
        The email address of the publisher.


        :return: The contact_email of this Publisher.
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """
        Sets the contact_email of this Publisher.
        The email address of the publisher.


        :param contact_email: The contact_email of this Publisher.
        :type: str
        """
        self._contact_email = contact_email

    @property
    def contact_phone(self):
        """
        Gets the contact_phone of this Publisher.
        The phone number of the publisher.


        :return: The contact_phone of this Publisher.
        :rtype: str
        """
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, contact_phone):
        """
        Sets the contact_phone of this Publisher.
        The phone number of the publisher.


        :param contact_phone: The contact_phone of this Publisher.
        :type: str
        """
        self._contact_phone = contact_phone

    @property
    def hq_address(self):
        """
        Gets the hq_address of this Publisher.
        The address of the publisher's headquarters.


        :return: The hq_address of this Publisher.
        :rtype: str
        """
        return self._hq_address

    @hq_address.setter
    def hq_address(self, hq_address):
        """
        Sets the hq_address of this Publisher.
        The address of the publisher's headquarters.


        :param hq_address: The hq_address of this Publisher.
        :type: str
        """
        self._hq_address = hq_address

    @property
    def logo(self):
        """
        Gets the logo of this Publisher.

        :return: The logo of this Publisher.
        :rtype: oci.marketplace.models.UploadData
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """
        Sets the logo of this Publisher.

        :param logo: The logo of this Publisher.
        :type: oci.marketplace.models.UploadData
        """
        self._logo = logo

    @property
    def links(self):
        """
        Gets the links of this Publisher.
        Reference links.


        :return: The links of this Publisher.
        :rtype: list[oci.marketplace.models.Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this Publisher.
        Reference links.


        :param links: The links of this Publisher.
        :type: list[oci.marketplace.models.Link]
        """
        self._links = links

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParserTestResult(object):
    """
    ParserTestResult
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParserTestResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param additional_info:
            The value to assign to the additional_info property of this ParserTestResult.
        :type additional_info: dict(str, str)

        :param entries:
            The value to assign to the entries property of this ParserTestResult.
        :type entries: list[oci.log_analytics.models.AbstractParserTestResultLogEntry]

        :param example_content:
            The value to assign to the example_content property of this ParserTestResult.
        :type example_content: str

        :param lines:
            The value to assign to the lines property of this ParserTestResult.
        :type lines: list[oci.log_analytics.models.AbstractParserTestResultLogLine]

        :param named_capture_groups:
            The value to assign to the named_capture_groups property of this ParserTestResult.
        :type named_capture_groups: list[str]

        """
        self.swagger_types = {
            'additional_info': 'dict(str, str)',
            'entries': 'list[AbstractParserTestResultLogEntry]',
            'example_content': 'str',
            'lines': 'list[AbstractParserTestResultLogLine]',
            'named_capture_groups': 'list[str]'
        }

        self.attribute_map = {
            'additional_info': 'additionalInfo',
            'entries': 'entries',
            'example_content': 'exampleContent',
            'lines': 'lines',
            'named_capture_groups': 'namedCaptureGroups'
        }

        self._additional_info = None
        self._entries = None
        self._example_content = None
        self._lines = None
        self._named_capture_groups = None

    @property
    def additional_info(self):
        """
        Gets the additional_info of this ParserTestResult.
        Additional information for the test result.


        :return: The additional_info of this ParserTestResult.
        :rtype: dict(str, str)
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """
        Sets the additional_info of this ParserTestResult.
        Additional information for the test result.


        :param additional_info: The additional_info of this ParserTestResult.
        :type: dict(str, str)
        """
        self._additional_info = additional_info

    @property
    def entries(self):
        """
        Gets the entries of this ParserTestResult.
        The test result log entries.


        :return: The entries of this ParserTestResult.
        :rtype: list[oci.log_analytics.models.AbstractParserTestResultLogEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """
        Sets the entries of this ParserTestResult.
        The test result log entries.


        :param entries: The entries of this ParserTestResult.
        :type: list[oci.log_analytics.models.AbstractParserTestResultLogEntry]
        """
        self._entries = entries

    @property
    def example_content(self):
        """
        Gets the example_content of this ParserTestResult.
        The example content.


        :return: The example_content of this ParserTestResult.
        :rtype: str
        """
        return self._example_content

    @example_content.setter
    def example_content(self, example_content):
        """
        Sets the example_content of this ParserTestResult.
        The example content.


        :param example_content: The example_content of this ParserTestResult.
        :type: str
        """
        self._example_content = example_content

    @property
    def lines(self):
        """
        Gets the lines of this ParserTestResult.
        The test result log lines.


        :return: The lines of this ParserTestResult.
        :rtype: list[oci.log_analytics.models.AbstractParserTestResultLogLine]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """
        Sets the lines of this ParserTestResult.
        The test result log lines.


        :param lines: The lines of this ParserTestResult.
        :type: list[oci.log_analytics.models.AbstractParserTestResultLogLine]
        """
        self._lines = lines

    @property
    def named_capture_groups(self):
        """
        Gets the named_capture_groups of this ParserTestResult.
        The named capture groups.


        :return: The named_capture_groups of this ParserTestResult.
        :rtype: list[str]
        """
        return self._named_capture_groups

    @named_capture_groups.setter
    def named_capture_groups(self, named_capture_groups):
        """
        Sets the named_capture_groups of this ParserTestResult.
        The named capture groups.


        :param named_capture_groups: The named_capture_groups of this ParserTestResult.
        :type: list[str]
        """
        self._named_capture_groups = named_capture_groups

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
